@@ -14,10 +14,11 @@ class CsvStyle(JsonEnum):
 
 
 class CsvFormatSettings(FileFormatSettings):
-    def __init__(self, schema=[]):
+    def __init__(self, schema=[], columnHeaders=False, delimiter=","):
         self.schema = schema + [
-            SchemaEntry("columnHeaders", bool, False),
-            SchemaEntry("delimiter", String, ","),
+            SchemaEntry("$type", String, "CsvFormatSettings"),
+            SchemaEntry("columnHeaders", bool, columnHeaders),
+            SchemaEntry("delimiter", String, delimiter),
             SchemaEntry("quoteStyle", CsvQuoteStyle, CsvQuoteStyle.Csv),
             SchemaEntry("csvStyle", CsvStyle, CsvStyle.QuoteAlways),
         ]
