@@ -283,7 +283,7 @@ class Model(DataObject):
         result["referenceModels"] = self.referenceModels.toJson()
         return result
 
-    def write_to_storage(self, entity_name, dataframe, writer, number_of_partition=None, fn=None, lit=None, model_json_name="model.json"):
+    def write_to_storage(self, entity_name, dataframe, writer, number_of_partition=None, fn=None, lit=None, model_json_name="model.json", columnHeaders=False, delimiter=","):
         entity = None
         entity_index = -1
         for _entity_index, _entity in enumerate(self.entities):
@@ -310,6 +310,7 @@ class Model(DataObject):
             partition.name = name
             partition.location = url
             partition.refreshTime = datetime.now().strftime('%Y-%m-%dT%H:%M:%S%z')
+            partition.fileFormatSetting = CsvFormatSettings(columnHeaders=columnHeaders, delimiter=delimiter)
             partitions.append(partition)
         entity.partitions = partitions
         random_sleep_time = random.randint(1, 5)
